@@ -88,10 +88,13 @@ class gjotsfile:
 		# nothing read from lockfile or process no longer exists:
 		if self.gui.trace:
 			print "lock_file: locking to pid", os.getpid()
-		fd = file(lockfile, "w")
-		fd.write("%d\n" % os.getpid())
-		fcntl.flock(fd, fcntl.LOCK_UN)
-		fd.close()
+		try:
+			fd = file(lockfile, "w")
+			fd.write("%d\n" % os.getpid())
+			fcntl.flock(fd, fcntl.LOCK_UN)
+			fd.close()
+		except IOError:
+			return (1, 0)
 		return (0, 0)
 		
 	def unlock_file(self, filename):
@@ -352,11 +355,13 @@ class gjotsfile:
 		
 		if mode == "w":
 			try:
-				f = open(filename)
-				f.close()
-				os.rename(filename, filename + "~")
-
-			except IOError:
+				backup_file = filename + "~"
+				s = os.stat(filename)
+				os.system("cp -f " + filename + " " + backup_file)
+				os.utime(backup_file, (s.st_atime, s.st_mtime))
+				os.chmod(backup_file, s.st_mode)
+				# os.chown(backup_file, s.st_uid, s.st_gid) ... not permitted!!
+			except OSError:
 				pass
 			
 		exti = filename.rfind(".cpt")
@@ -655,12 +660,16 @@ class gjotsfile:
 							self.filename = self.prompt_filename
 							self.gui.set_title(basename)
 					break
-				
+				else:  # self.fileselectionValue != OK
+					return ""
 			else: # just save the sucker
 				# assert exporting == 0
 				retval = self._do_store(self.filename, exporting)
 				break
-			
+
+# developers may want to enable this to check the before & after file images:
+#		if self.gui.dev:
+#			os.system("meld " + self.prompt_filename + " " + self.prompt_filename + "~")
 		return retval
 			
 	def __init__(self, gui):
