@@ -69,9 +69,6 @@ class sort_dialog:
 		w = self.xml.get_widget("sortAlphabeticRadioButton")
 		if w:
 			self.gui.client.set_bool(self.gui.sort_alpha_path, w.get_active())
-		w = self.xml.get_widget("sortItemsRadioButton")
-		if w:
-			self.gui.client.set_bool(self.gui.sort_items_path, w.get_active())
 
 		w = self.xml.get_widget("sortSublevelsSpinButton")
 		if w:
@@ -107,14 +104,14 @@ class sort_dialog:
 		w = self.xml.get_widget("sortAlphabeticRadioButton")
 		if w:
 			sort_alpha = w.get_active()
-		w = self.xml.get_widget("sortItemsRadioButton")
-		if w:
-			sort_items = w.get_active()
 
 		w = self.xml.get_widget("sortSublevelsSpinButton")
 		if w:
 			sort_sublevels = w.get_value_as_int()
-		
+
+		if self.type == "tree":
+			sort_items = True
+
 		return sort_ascending, sort_alpha, sort_items, sort_sublevels
 			
 	def _sort_item(self, item, start_iter, end_iter, sort_ascending, sort_alpha, sort_sublevels, level):
@@ -276,21 +273,7 @@ class sort_dialog:
 		self.destroy()
 		return
 
-	def on_sortItemsRadioButton_toggled(self, b):
-		if self.gui.trace:
-			print inspect.getframeinfo(inspect.currentframe())[2]
-		print "toggled"
-		w = self.xml.get_widget("sortItemsRadioButton")
-		if w:
-			sort_items = w.get_active()
-		w = self.xml.get_widget("sortSublevelsSpinButton")
-		if w:
-			w.set_sensitive(sort_items)
-		w = self.xml.get_widget("sortSublevelsLabel")
-		if w:
-			w.set_sensitive(sort_items)
-		
-	def __init__(self, gui):
+	def __init__(self, gui, type):
 		"""
 		Print dialog
 		"""
@@ -304,38 +287,28 @@ class sort_dialog:
 			"on_sortCommandEntry_key_press_event":		self.on_sortCommandEntry_key_press_event,
 			"on_sortOKButton_clicked":					self.on_sortOKButton_clicked,
 			"on_sortCancelButton_clicked":				self.on_sortCancelButton_clicked,
-			"on_sortItemsRadioButton_toggled":			self.on_sortItemsRadioButton_toggled,
 		}
 		self.name = "sortDialog"
 		self.xml = gtk.glade.XML(self.gui.gui_filename, self.name)
 		self.xml.signal_autoconnect(callbacks)
 
+		# Initialize the GUI state of the radio buttons and spin button
+		# based on the type of sort ('tree', 'text', or 'both')
+
+		# TODO: Shouldn't we be setting each radio button???
 		w = self.xml.get_widget("sortAscendingRadioButton")
-		if w:
-			w.set_active(self.gui.client.get_bool(self.gui.sort_ascending_path))
-
+		w.set_active(self.gui.client.get_bool(self.gui.sort_ascending_path))
 		w = self.xml.get_widget("sortAlphabeticRadioButton")
-		if w:
-			w.set_active(self.gui.client.get_bool(self.gui.sort_alpha_path))
-			
-		sort_items = 0
-		w = self.xml.get_widget("sortItemsRadioButton")
-		if w:
-			sort_items = self.gui.client.get_bool(self.gui.sort_items_path)
-			w.set_active(sort_items)
-		else:
-			print "Can't open sort_items widget"
-		print "sort_items = ", sort_items, "path = ", self.gui.sort_items_path
+		w.set_active(self.gui.client.get_bool(self.gui.sort_alpha_path))
 
-		w = self.xml.get_widget("sortSublevelsSpinButton")
-		if w:
-			w.set_value(self.gui.client.get_int(self.gui.sort_sublevels_path))
-			w.set_sensitive(sort_items)
-		w = self.xml.get_widget("sortSublevelsLabel")
-		if w:
-			w.set_sensitive(sort_items)
-
-		#self.gui.client.notify_add(self.gui.sort_items_path, self.on_sortItemsRadioButton_toggled, self.gui.gjots)
+		if type == "tree":
+			self.type = "tree"
+			self.xml.get_widget("sortSublevelsSpinButton").set_sensitive(True)
+			self.xml.get_widget("sortDialog").set_title("Sort Tree")
+		elif type == "text":
+			self.type = "text"
+			self.xml.get_widget("sortRangeFrame").hide()
+			self.xml.get_widget("sortDialog").set_title("Sort Text")
 
 		return
 		
